@@ -2,13 +2,21 @@
 #'
 #' @description
 #' Transform 'HUMAnN' metagenomic results to microtable object, reference: Franzosa et al. (2018) <doi:10.1038/s41592-018-0176-y>.
-#' @param abund_table 'HUMAnN' output abundance table, see the example.
-#' @param db default "MetaCyc"; either "MetaCyc" or "KEGG"; the pathway database used in the abund_table file generation.
-#' @param sample_data default NULL; the sample metadata table, must be tab or comma seperated file, generally, a file with suffix "tsv" or "csv".
-#' @param match_table default NULL; a two column table used to replace the sample names in HUMAnN abundance result; Must be two columns with no column names;
-#'    The first column must be sample names same with those in abund_table, the second column is the new sample names, e.g., the rownames in sample_table. See the example files.
-#' @param ... parameter passed to microtable$new function of microeco package, such as auto_tidy parameter.
-#' @return microtable object.
+#' @param feature_table file path of 'HUMAnN' output abundance table; Please see the example.
+#' @param db default "MetaCyc"; either "MetaCyc" or "KEGG"; the pathway database used in the feature_table file generation.
+#' @param sample_table default NULL; sample metadata table; If provided, must be one of the several types of formats: \cr
+#'   1) comma seperated file with the suffix csv or tab seperated file with suffix tsv or txt; \cr
+#'   2) Excel type file with the suffix xlsx or xls; require \code{readxl} package to be installed; \cr
+#'   3) \code{data.frame} object from R.
+#' @param match_table default NULL; a two column table used to replace the sample names in feature table; Must be two columns without column names;
+#'   The first column must be raw sample names same with those in feature table, 
+#'   the second column must be new sample names same with the rownames in sample_table; Please also see the example files.
+#'   If provided, must be one of the several types of formats: \cr
+#'   1) comma seperated file with the suffix csv or tab seperated file with suffix tsv/txt; \cr
+#'   2) Excel type file with the suffix xlsx or xls; require \code{readxl} package to be installed; \cr
+#'   3) \code{data.frame} object from R.
+#' @param ... parameter passed to \code{microtable$new} function of \code{microeco} package, such as \code{auto_tidy} parameter.
+#' @return \code{microtable} object.
 #' @examples
 #' \donttest{
 #' library(file2meco)
@@ -21,10 +29,10 @@
 #' # use the raw data files stored inside the package for MetaCyc pathway database based analysis
 #' abund_file_path <- system.file("extdata", "example_HUMAnN_MetaCyc_abund.tsv", package="file2meco")
 #' # the default db is "MetaCyc"
-#' humann2meco(abund_table = abund_file_path, db = "MetaCyc")
-#' humann2meco(abund_table = abund_file_path, db = "MetaCyc", sample_data = sample_file_path, 
+#' humann2meco(abund_file_path, db = "MetaCyc")
+#' humann2meco(abund_file_path, db = "MetaCyc", sample_table = sample_file_path, 
 #'   match_table = match_file_path)
-#' test <- humann2meco(abund_table = abund_file_path, db = "MetaCyc", sample_data = sample_file_path, 
+#' test <- humann2meco(abund_file_path, db = "MetaCyc", sample_table = sample_file_path, 
 #'   match_table = match_file_path)
 #' test$tidy_dataset()
 #' # rel = FALSE donot use relative abundance
@@ -54,9 +62,9 @@
 #' #############################################################
 #' # KEGG pathway examples
 #' abund_file_path <- system.file("extdata", "example_HUMAnN_KEGG_abund.tsv", package="file2meco")
-#' humann2meco(abund_table = abund_file_path, db = "KEGG")
-#' test <- humann2meco(abund_table = abund_file_path, db = "KEGG", 
-#'   sample_data = sample_file_path, match_table = match_file_path)
+#' humann2meco(abund_file_path, db = "KEGG")
+#' test <- humann2meco(abund_file_path, db = "KEGG", 
+#'   sample_table = sample_file_path, match_table = match_file_path)
 #' test$tax_table %<>% subset(Level.1 != "unclassified")
 #' test$tidy_dataset()
 #' # rel = FALSE donot use relative abundance
@@ -77,9 +85,9 @@
 #' test1$plot_diff_bar(threshold = 2)
 #' }
 #' @export
-humann2meco <- function(abund_table, db = c("MetaCyc", "KEGG")[1], sample_data = NULL, match_table = NULL, ...){
+humann2meco <- function(feature_table, db = c("MetaCyc", "KEGG")[1], sample_table = NULL, match_table = NULL, ...){
 	# first check func_data file format.
-	abund_raw <- read.delim(abund_table, check.names = FALSE, row.names = 1, stringsAsFactors = FALSE)
+	abund_raw <- read.delim(feature_table, check.names = FALSE, row.names = 1, stringsAsFactors = FALSE)
 
 	# recalculate the abundance for unclassified
 	abund_rawname <- rownames(abund_raw)
@@ -157,10 +165,10 @@ humann2meco <- function(abund_table, db = c("MetaCyc", "KEGG")[1], sample_data =
 		abund_new <- check_match_table(match_table = match_table, abund_new = abund_new)
 	}
 	# read sample metadata table
-	if(!is.null(sample_data)){
-		sample_data <- check_sample_table(sample_data = sample_data)
+	if(!is.null(sample_table)){
+		sample_table <- check_sample_table(sample_table = sample_table)
 	}
-
-	dataset <- microtable$new(otu_table = abund_new, sample_table = sample_data, tax_table = tax_table, ...)
+	
+	dataset <- microtable$new(otu_table = abund_new, sample_table = sample_table, tax_table = tax_table, ...)
 	dataset
 }
